CompensatingWriteError class final Sync

An error type that describes a compensating write error, which indicates that one more object changes have been reverted by the server.

Inheritance

Properties

code → SyncErrorCode
The code that describes this error.
finalinherited
compensatingWrites ↔ List<CompensatingWriteInfo>?
The list of the compensating writes performed by the server.
latefinal
hashCode → int
The hash code for this object.
no setterinherited
innerError → Object?
finalinherited
message → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited