CompensatingWriteInfo class Sync

Contains the details for a compensating write performed by the server.

Constructors

CompensatingWriteInfo(String objectType, String reason, RealmValue primaryKey)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
objectType → String
The type of the object which was affected by the compensating write.
final
primaryKey → RealmValue
The primary key of the object which was affected by the compensating write.
final
reason → String
The reason for the server to perform a compensating write.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited