LocalConfiguration class Configuration

LocalConfiguration is used to open local Realm instances, that are persisted across runs.

Inheritance

Properties

disableFormatUpgrade → bool
Specifies if a realm file format should be automatically upgraded if it was created with an older version of the Realm library. An exception will be thrown if a file format upgrade is required.
final
encryptionKey → List<int>?
The key used to encrypt the entire Realm.
finalinherited
fifoFilesFallbackPath → String?
Specifies the FIFO special files fallback location.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
initialDataCallback → InitialDataCallback?
Called when opening a Realm for the very first time, when db file is created.
final
isReadOnly → bool
Specifies whether a Realm should be opened as read-only.
final
maxNumberOfActiveVersions → int?
Sets the maximum number of active versions allowed before an exception is thrown.
finalinherited
migrationCallback → MigrationCallback?
Called when opening a Realm with a schema version that is newer than the one used to create the file.
final
path ↔ String
The path where the Realm should be stored.
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaObjects → Iterable<SchemaObject>
A collection of SchemaObject that will be used to construct the RealmSchema once the Realm is opened.
finalinherited
schemaVersion → int
The schema version used to open the Realm. If omitted, the default value is 0.
final
shouldCompactCallback → ShouldCompactCallback?
Called when opening a Realm for the first time, after process start.
final
shouldDeleteIfMigrationNeeded → bool
Specifies if a realm file should be deleted in case the schema on disk doesn't match the schema in code. Setting this to true can lead to data loss.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited